function varargout = peldagui(varargin)
% PELDAGUI MATLAB code for peldagui.fig
%      PELDAGUI, by itself, creates a new PELDAGUI or raises the existing
%      singleton*.
%
%      H = PELDAGUI returns the handle to a new PELDAGUI or the handle to
%      the existing singleton*.
%
%      PELDAGUI('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in PELDAGUI.M with the given input arguments.
%
%      PELDAGUI('Property','Value',...) creates a new PELDAGUI or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before peldagui_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to peldagui_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help peldagui

% Last Modified by GUIDE v2.5 23-Sep-2014 08:30:09

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @peldagui_OpeningFcn, ...
                   'gui_OutputFcn',  @peldagui_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before peldagui is made visible.
function peldagui_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to peldagui (see VARARGIN)

% Choose default command line output for peldagui
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes peldagui wait for user response (see UIRESUME)
% uiwait(handles.figure1);

    % saját rész: kezdeti állapot
    global x; %ezek a számolt pontok
    x = 0:0.01:2*pi; % az ábrázolt tartomány [0 2*pi] intervallum 0.01-es lépésközökkel 
    %kezdeti kirajzolás: az ábra mezõre ábrázolom az x függvényében a sin(x * csúszka értéket)
    plot(handles.abra, x, sin(x*get(handles.frekvencia, 'Value')));
    
% --- Outputs from this function are returned to the command line.
function varargout = peldagui_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


% --- Executes on slider movement.
function frekvencia_Callback(hObject, eventdata, handles)
% hObject    handle to frekvencia (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'Value') returns position of slider
%        get(hObject,'Min') and get(hObject,'Max') to determine range of slider
    
    % saját rész: a csúszka változtatásakor:
    global x; %a pontok, ahol ábrázolok
    % a csúszka (frekvencia) adott értéke frekvenciájú szinuszt kirajzol az x függvényében az ábra mezõre
    plot(handles.abra, x, sin(x*get(handles.frekvencia, 'Value')));
    
    %csuszka értékét kiírja a bemeneti mezõre is:
    ertek=get(handles.frekvencia, 'Value');
    set(handles.frekvir, 'String', num2str(ertek)); %szöveges mezõre kiírja
    
    % a képletben megjelenik a csúszka aktuális értéke:
    kiirt_szoveg=['f(x)=sim(', num2str(ertek), '*x)']; %a kiírandó szöveget összefésül: az 1. szöveget és a számértéket és a képlet végét egymás után rakja
    set(handles.frekvkiir, 'String', kiirt_szoveg); %szöveges mezõre kiírja a képletet
    

% --- Executes during object creation, after setting all properties.
function frekvencia_CreateFcn(hObject, eventdata, handles)
% hObject    handle to frekvencia (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: slider controls usually have a light gray background.
if isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor',[.9 .9 .9]);
end


% --- Executes on button press in resetbutton.
function resetbutton_Callback(hObject, eventdata, handles)
% hObject    handle to resetbutton (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

    % saját rész: a csúszka változtatásakor:
    global x; %a pontok, ahol ábrázolok
    %alapértelmezett 1 frekvenciát állít vissza
    alap=1;
    %ábrázolom:
    plot(handles.abra, x, sin(x*alap));
    % a képlet:
    kiirt_szoveg=['f(x)=sim(',num2str(alap),'*x)'];
    set(handles.frekvkiir, 'String', kiirt_szoveg); %szöveges mezõre kiírja képletet
    %átír szöveges mezõre is frekvencia értéket:
    set(handles.frekvir, 'String', num2str(alap)); %szöveges mezõre kiírja
    %csuszkára írom át a frekvencia alap értékét:
    set(handles.frekvencia, 'Value', alap);


function frekvir_Callback(hObject, eventdata, handles)
% hObject    handle to frekvir (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of frekvir as text
%        str2double(get(hObject,'String')) returns contents of frekvir as a double

    % saját rész: a csúszka változtatásakor:
    global x; %a pontok, ahol ábrázolok
    %beveszem a szövegmezõbõl az értéket (a szöveget számmá kell alakítani)
    frekv=str2double(get(handles.frekvir,'String'));
    
    % ábrázolom
    plot(handles.abra, x, sin(x*frekv));
    % a képletben megjelenik a csúszka aktuális értéke:
    kiirt_szoveg=['f(x)=sim(', get(handles.frekvir,'String'), '*x)']; %a kiírandó szöveget összefésül: az 1. szöveget és a számértéket és a képlet végét egymás után rakja
    set(handles.frekvkiir, 'String', kiirt_szoveg); %szöveges mezõre kiírja képletet
    
    %csuszkára írom át bemeneti szövegmezõ értékét:
    set(handles.frekvencia, 'Value', frekv);
   

% --- Executes during object creation, after setting all properties.
function frekvir_CreateFcn(hObject, eventdata, handles)
% hObject    handle to frekvir (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
